@@ -3,11 +3,13 @@
 {
     'name': 'Analytic Purchase',
     'name_bg_BG': 'Аналитични покупки',
+    'name_ca_ES': 'Compra analítica',
     'name_de_DE': 'Kostenstellen Einkauf',
+    'name_es_AR': 'Compra Analítica',
     'name_es_CO': 'Compra Analítica',
     'name_es_ES': 'Compra analítica',
     'name_fr_FR': 'Achat analytique',
-    'version': '2.0.1',
+    'version': '2.4.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -15,11 +17,16 @@
 ''',
     'description_bg_BG': '''Добавя аналитична сметка към редовете на покупка
 ''',
+    'description_ca_ES': '''Afegeix comptabilitat analítica a les línies de les
+comandes de compra.''',
     'description_de_DE': '''Fügt kostenstellen zu Einkaufspositionen hinzu
+''',
+    'description_es_AR': '''Añade contabilidad analítica a las líneas de compra.
 ''',
     'description_es_CO': '''Adiciona contabilidad analítica a las líneas de compra.
 ''',
-    'description_es_ES': 'Añade contabilidad analítica a las líneas de compra.',
+    'description_es_ES': '''Añade contabilidad analítica a las líneas de los
+pedidos de compra.''',
     'description_fr_FR': 'Ajoute la comptabilité analytique sur les lignes d\'achat.',
     'depends': [
         'purchase',
@@ -30,10 +37,15 @@
         'purchase.xml',
     ],
     'translation': [
-        'bg_BG.csv',
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
+        'locale/bg_BG.po',
+        'locale/ca_ES.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_AR.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
